pub fn provider_cache_key<P, Param>(provider: P, param: Param) -> Stringwhere
P: Provider<Param>,
Param: ProviderParamBounds,Expand description
Helper function to create cache keys for providers with parameters
pub fn provider_cache_key<P, Param>(provider: P, param: Param) -> Stringwhere
P: Provider<Param>,
Param: ProviderParamBounds,Helper function to create cache keys for providers with parameters